function y = Lambda_noinv(x, nu, mu, a, b, eps)
%
% a non-invertible map
% [see England & Krauskopf & Osinga, SIAM JADS 3(2):
% 161-190, 2004 (example 4.3)]
%
%      x -> x^4 + nu*x^2 + x*y + mu*x
% L :
%      y -> (1 + a)*y + b + epsilon*x^2
%

if (length(x) ~= 2)
    cprintf('err', 'ERROR: First argument must be a vector with 2 elements.\n');
    y = [];
    return;
else
    y(1) = x(1)^4 + nu*x(1)^2 + x(1)*x(2) + mu*x(1);
    y(2) = (1 + a)*x(2) + b + eps*x(1)^2;
end;

