function y = gclm(x, a, eps, dim)
%
% globally coupled logistic maps
% 
% Phi: x_i -> (1 - epsilon)*f(x_i) + 
%             epsilon/N*(f(x_1) + ... + f(x_N)), i = 1..N
% 
% f(x) = a*x*(1 - x)
%

if (length(x) ~= dim)
    cprintf('err', 'ERROR: The initial vector has wrong dimension.\n');
    y = [];
    return;
else
    f = a.*x.*(1 - x);
    total = 0;
    for i = 1:dim
        total = total + f(i);
    end;
    for i = 1:dim
        y(i) = (1 - eps)*f(i) + eps*total/dim;
    end;
end
