function y = ikeda(x, A, b, e, phi, q)
%
% modified Ikeda map
% [see England & Krauskopf & Osinga, SIAM JADS 3(2):
% 161-190, 2004 (example 4.2)]
%
% 
%     /x1\      / A + b*x1*cos(m) - e*x2*sin(m) \
% g: (    ) -> (                                 )
%     \x2/      \ b*x2*cos(m) + e*x1*sin(m)     /
%
%   m = phi - q/(1 + x1^2 + x2^2)
%
%

if (length(x) ~= 2)
    cprintf('err', 'ERROR: First argument must be a vector with 2 elements.\n');
    y = [];
    return;
else
    m = phi - q/(1 + x(1)^2 + x(2)^2);
    y(1) = A + b*x(1)*cos(m) - e*x(2)*sin(m);
    y(2) = b*x(2)*cos(m) + e*x(1)*sin(m);
end;
