function J = ikeda_J(x, A, b, e, phi, q)
%
% modified Ikeda map: Jacobi matrix
% [see England & Krauskopf & Osinga, SIAM JADS 3(2):
% 161-190, 2004 (example 4.2)]
%

if (length(x) ~= 2)
    cprintf('err', 'ERROR: First argument must be a vector with 2 elements.\n');
    y = [];
    return;
else
    J = zeros(2, 2);
    d = 1 + x(1)^2 + x(2)^2;
    m = phi - q/d;
    J(1, 1) = b*cos(m) - 2*b*x(1)^2*sin(m)*q/d^2 - 2*e*x(2)*cos(m)*q*x(1)/d^2;
    J(1, 2) = - 2*b*x(1)*sin(m)*q*x(2)/d^2 - e*sin(m) - 2*e*x(2)^2*cos(m)*q/d^2;
    J(2, 1) = - 2*b*x(1)*sin(m)*q*x(2)/d^2 + e*sin(m) + 2*e*x(1)^2*cos(m)*q/d^2;
    J(2, 2) = b*cos(m) - 2*b*x(2)^2*sin(m)*q/d^2 + 2*e*x(2)*cos(m)*q*x(1)/d^2;
end;
