function y = pwl3part(x, al, ar, ml, mr, dl, dr)
%
% piecewise linear map defined on 3 partitions
% 
%                   / al*x + ml,  x <= dl
%                  /  
%  f: x -> f(x) = {   am*x + mm,  dl < x <= dr    
%                  \
%                   \ ar*x + mr,  x > dr 
%
% am = (mr - ml + ar*dr - al*dl)/(dr - dl)
% mm = ((al - ar)*dl*dr + ml*dr - mr*dl)/(dr - dl)
%


am = (mr - ml + ar*dr - al*dl)/(dr - dl);
mm = ((al - ar)*dl*dr + ml*dr - mr*dl)/(dr - dl);

if (x <= dl)
    y = al*x + ml;
elseif (x <= dr)
    y = am*x + mm;
else
    y = ar*x + mr;
end;


