function period = find_period(fhandle, x0, trans, maxperiod, tolerance, varargin)

%
% Find period of the orbit of the function fhandle 
% starting from initial point x0
%
% fhandle   - function (dynamical system) handle
% x0        - target point
% trans     - transient time
% maxperiod - maximal period to find
% tolerance - tolerance value to find period
% varargin  - cell array of the function parameters
%

x = iterate(fhandle, x0, trans, 1, varargin{:});

if isfinite(x)
    period = 0;
    x1 = x;
    for i = 1:maxperiod
        x1 = fhandle(x1, varargin{:});
        if (max(abs(x1 - x)) < tolerance)
            period = i;
            break;
        end;
    end;
else
    period = -1;
end;



