function div = make_subdiv(range, nums)

%
% Make a subdivision of a multi-dimensional domain into a 
% number of subdomains. 
% 
% range - matrix defining the domain, each row is a range
%         for the corresponding coordinate 
% nums  - a vector of subdivision numbers for each dimension
%
% return values:
% div - the cell array of matrices defining the subdomains
%       (each row is a range for the corresponding
%       coordinate) 
%


% dimension of the domain
dim = length(range(:, 1));

if (length(nums) < dim)
    error('The second argument must be of the same length as the target domain dimension');
    cprintf('err', ['The second argument must be of the same length as the ' ...
                    'target domain dimension.\n']);
end

% increments and total number of subdomains
total = 1;
for i = 1:dim
    delta(i) = (range(i, 2)  - range(i, 1))/nums(i);
    total = total*nums(i);
end

div = {};
for j = 1:total
    div{j} = [];
    
    ki = 1;
    cur_num = total;
    jj = j;
    for i = 1:dim
        cur_num = cur_num/nums(i);
        ki = ceil(jj/cur_num);
        jj = jj - (ki - 1)*cur_num;

        div{j}(i, :) = [(range(i, 1) + (ki-1)*delta(i)) (range(i, 1) + ki*delta(i))];
    end
end

div = div';




